@@ -1,11 +1,9 @@
 import dataclasses
 import datetime
-import logging
 import typing
 
 import wialon.api
 from django.conf import settings
-from django.utils import timezone
 from loguru import logger
 
 
@@ -20,10 +18,22 @@ class WialonAPICall:
 
 
 class Wialon(wialon.api.Wialon):
-    def __init__(self, log_level: int = logging.INFO, *args, **kwargs) -> None:
+    def __init__(
+        self,
+        debug: bool = False,
+        log_level: int = 10,
+        log_days: int = 10,
+        *args,
+        **kwargs,
+    ) -> None:
         super().__init__(*args, **kwargs)
         self.call_history: list[WialonAPICall] = []
-        logger.add(self.__class__.__name__, level=log_level)
+        logger.add(
+            f"logs/{self.__class__.__name__}.log",
+            level=log_level,
+            retention=f"{log_days} days",
+            diagnose=debug,
+        )
 
     @property
     def total_calls(self) -> int:
@@ -36,7 +46,10 @@ class Wialon(wialon.api.Wialon):
     def call(self, action_name: str, *argc, **kwargs) -> typing.Any:
         logger.debug(f"Executing '{action_name}'...")
         call_record = WialonAPICall(
-            action=action_name, timestamp=timezone.now(), args=argc, kwargs=kwargs
+            action=action_name,
+            timestamp=datetime.datetime.now(),
+            args=argc,
+            kwargs=kwargs,
         )
 
         try:
@@ -60,7 +73,9 @@ class WialonSession:
         scheme: str = "https",
         host: str = "hst-api.wialon.com",
         port: int = 443,
-        log_level: int = logging.INFO,
+        log_level: int = 10,
+        log_days: int = 10,
+        debug: bool = False,
     ) -> None:
         """
         Starts or continues a Wialon API session.
@@ -75,21 +90,34 @@ class WialonSession:
         :type host: :py:obj:`str`
         :param port: Wialon API host port. Default is ``443``.
         :type port: :py:obj:`int`
-        :param log_level: Level of emitted logs. Default is :py:obj:`~logging.INFO`.
+        :param log_level: Level of emitted logs. Default is ``10``.
         :type log_level: :py:obj:`int`
         :returns: Nothing.
         :rtype: :py:obj:`None`
 
         """
 
-        logger.add(self.__class__.__name__, level=log_level)
-        self._token = token or settings.WIALON_TOKEN
+        logger.add(
+            f"logs/{self.__class__.__name__}.log",
+            level=log_level,
+            retention=f"{log_days} days",
+            diagnose=debug or settings.DEBUG if settings.configured else False,
+        )
+        self._token = token or settings.WIALON_TOKEN if settings.configured else None
         self._username = None
         self._gis_sid = None
         self._hw_gp_ip = None
         self._wsdk_version = None
         self._uid = None
-        self.wialon_api = Wialon(scheme=scheme, host=host, port=port, sid=sid)
+        self.wialon_api = Wialon(
+            scheme=scheme,
+            host=host,
+            port=port,
+            sid=sid,
+            log_level=log_level,
+            log_days=log_days,
+            debug=debug,
+        )
 
     def __str__(self) -> str:
         return str(self.id)
